<?php 
    LogAdmin::insert([
        'user_id'       => Session::getInfo('id'),
        'log_action'    => 'view_screen',
        'log_file'      => __FILE__,
        'log_success'   => true
    ]);

    $bestEvents = Event::getBy([
        'status' => 1, 
        'event_interest.positive' => 1, 
        '(event_end_date >= NOW())' => 1
    ], ['event.*', 'COUNT(DISTINCT event_follow.id) AS followers'], false, [
        'event_follow' => [
            'event_follow.event_id' => 'event.id'
        ],
        'event_interest' => [
            'event_interest.id' => 'event_follow.interest_id'
        ]
    ], [], 'event.id', false, 'followers DESC', 15);
    $newEvents = Event::getBy(['status' => 1], ['*'], false, [], [], false, false, 'date_insert DESC', 15);
    $nextEvents = Event::getBy(['status' => 1, '(event_start_date >= NOW())' => 1], ['*'], false, [], [], false, false, 'event_start_date', 15);
    $newUsers = User::getBy(['status' => 1], ['*'], false, [], [], false, false, 'id DESC', 15);
?>

<style>
.title h4 {
    font-weight: 100;
}

#best-events, #new-events, #next-events, #new-users {
    height: 241px;
    overflow: auto;
}
</style>

<div class="container">
    <h2>
        Dashboard
    </h2>

    <div class="row">
        <div class="col s12">
            <ul class="tabs">
                <li class="tab col s3" title="Eventos Bombando"><a class="active" href="#best-events">Eventos Bombando</a></li>
                <li class="tab col s3" title="Novos Eventos"><a href="#new-events">Novos Eventos</a></li>
                <li class="tab col s3" title="Próximos Eventos"><a href="#next-events">Próximos Eventos</a></li>
                <li class="tab col s3" title="Novos Usuários"><a href="#new-users">Novos Usuários</a></li>
            </ul>
        </div>

        <div id="best-events" class="col s12">
            <table class="register-list striped highlight display">
                <thead>
                    <tr>
                        <td>
                            Nome
                        </td>
                        <td>
                            Interessados
                        </td>
                        <td>
                            Data
                        </td>
                        <td>
                        </td>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($bestEvents as $Registro) : ?>
                        <tr data-id="<?=$Registro->id?>">
                            <td>
                                <a href="<?=SITE_URL?>evento/<?=$Registro->event_url?>"><?=$Registro->event_name?></a>
                            </td>
                            <td>
                                <?=$Registro->followers?>
                            </td>
                            <td>
                                <?=($Registro->event_start_date)('d/m/Y H:i')?>
                            </td>
                            <td class="center">
                                <a href="<?=ADMIN_URL?>eventos/<?=$Registro->id?>/estatisticas/">
                                    <i class="icon-chart small main-color-text darken-1" title="Estatísticas"></i>
                                </a>
                            </td>
                        </tr>
                    <?php endforeach ?>
                </tbody>
            </table>
        </div>

        <div id="new-events" class="col s12">
            <table class="register-list striped highlight display">
                <thead>
                    <tr>
                        <td>
                            Nome
                        </td>
                        <td>
                            Data
                        </td>
                        <td>
                        </td>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($newEvents as $Registro) : ?>
                        <tr data-id="<?=$Registro->id?>">
                            <td>
                                <a href="<?=SITE_URL?>evento/<?=$Registro->event_url?>"><?=$Registro->event_name?></a>
                            </td>
                            <td>
                                <?=($Registro->event_start_date)('d/m/Y H:i')?>
                            </td>
                            <td class="center">
                                <a href="<?=ADMIN_URL?>eventos/<?=$Registro->id?>/estatisticas/">
                                    <i class="icon-chart small main-color-text darken-1" title="Estatísticas"></i>
                                </a>
                            </td>
                        </tr>
                    <?php endforeach ?>
                </tbody>
            </table>
        </div>
        <div id="next-events" class="col s12">
            <table class="register-list striped highlight display">
                <thead>
                    <tr>
                        <td>
                            Nome
                        </td>
                        <td>
                            Data
                        </td>
                        <td>
                        </td>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($nextEvents as $Registro) : ?>
                        <tr data-id="<?=$Registro->id?>">
                            <td>
                                <a href="<?=SITE_URL?>evento/<?=$Registro->event_url?>"><?=$Registro->event_name?></a>
                            </td>
                            <td>
                                <?=($Registro->event_start_date)('d/m/Y H:i')?>
                            </td>
                            <td class="center">
                                <a href="<?=ADMIN_URL?>eventos/<?=$Registro->id?>/estatisticas/">
                                    <i class="icon-chart small main-color-text darken-1" title="Estatísticas"></i>
                                </a>
                            </td>
                        </tr>
                    <?php endforeach ?>
                </tbody>
            </table>
        </div>
        <div id="new-users" class="col s12">
            <ul class="collection register-list">
                <?php foreach ($newUsers as $User) : ?>
                    <li class="collection-item">
                        <b class="title">
                            <a href="<?=SITE_URL?>perfil/<?=$User->id?>">
                                <?=$User->name?> 
                            </a>
                            <a href="<?=ADMIN_URL?>usuarios/<?=$User->id?>/estatisticas/" class="right">
                                <i class="icon-chart small main-color-text darken-1 tooltipped" data-tooltip="Estatísticas"></i> 
                            </a>
                        </b>
                    </li>
                <?php endforeach ?>
            </ul>
        </div>
    </div>
</div>

<script type="text/javascript">
$(function () {
    var goingDown = true,
    nextScrollTimeout, nextUpdateTimeout;

    function doActiveTabAnimation() {
        return;

        var $activeTab = $('.col.active');
        if (!$activeTab.length)
            return setTimeout(doActiveTabAnimation, 1000);

        $activeTab.stop();
        var scrollTop = $activeTab.scrollTop(),
            scrollHeight = $('.register-list', $activeTab).get(0).scrollHeight,
            distance = !goingDown ? 0 : scrollHeight,
            fullTime = 30000,
            time;
        
        if (goingDown) {
            time = fullTime * ((distance - scrollTop) / distance);
        } else {
            time = fullTime * ((scrollHeight - (scrollHeight - scrollTop - 218)) / scrollHeight); 
        }
        $activeTab.animate({
            scrollTop: distance
        }, {
            duration: time,
            complete: function() {
                goingDown = !goingDown;
                nextScrollTimeout = setTimeout(doActiveTabAnimation, 1300)
            }
        });
    }

    $('#best-events, #new-events, #next-events, #new-users').hover(function(e) {
        $(this).stop()
        if (nextScrollTimeout)
            clearTimeout(nextScrollTimeout)
    }, doActiveTabAnimation)

    doActiveTabAnimation()

    $('.tabs .tab').on('click', function(){
        setTimeout(doActiveTabAnimation, 90)
    })

    function updateActiveList() {
        var $activeTab = $('.col.active');
        if (!$activeTab.length)
            return setTimeout(updateActiveList, 1000);

        $.ajax({
            url:            '<?=ADMIN_URL?>getMainFeed.ajax',
            type:           'get',
            dataType:       'html',
            data:           {
                tab: $activeTab.attr('id')
            },
            success:      (res) => {
                $activeTab.html(res);
                nextUpdateTimeout = setTimeout(updateActiveList, 2000)
            }
        });
    }

    updateActiveList()
});
</script>