<?php

class Database {
	private $pdo;

	public function start($host = HOST, $user = USER, $pass = PASS, $schema = SCHEMA) {
		$this->pdo = new PDO("mysql:host={$host};dbname={$schema};charset=utf8mb4", $user, $pass);
	}

	public function kill() {
		$this->pdo->query('KILL CONNECTION_ID();');
		$this->pdo = null;
	}

	public function manualCommit() {
		$this->pdo->beginTransaction();
	}

	public function commit() {
		$this->pdo->commit();
	}

	public function rollBack() {
		$this->pdo->rollBack();
	}

	function query($sql, $args = array()) {
		$autoInit = !($this->pdo instanceof PDO);
		if ($autoInit)
			$this->start();
		
		foreach ($args as &$arg) {
			$arg = (string) $arg;
		}
		
		$stmt = $this->pdo->prepare($sql);

		if ($stmt === false) {
			debug_log($this->pdo->errorInfo(), func_get_args());
			return false;
		}
		
		$success = $stmt->execute($args);
		$result = $stmt->fetchAll(PDO::FETCH_ASSOC);

		if (!$success) {
			debug_log($stmt->errorInfo(), func_get_args());
			return false;
		}

		$lastId = $this->pdo->lastInsertId();

		$stmt->closeCursor();
		$stmt = null;

		if ($autoInit)
			$this->kill();
		
		return array(
			'result' => $result, 
			'lastId' => $lastId
		);
	}
}
?>
