<?php
    class Event {
        use CRUD;

        const _TABLE = 'event';

        static function getUserEventsForMonth($timestamp, $userId = false) {
            if (!$userId)
                $userId = Session::getInfo('id');
                
            $sql = 
                "SELECT 
                    event.event_name as event_name,
                    event.id as event_id,
                    event.event_url as event_url,
                    event_start_date AS event_date,
                    arquivos.arquivo as event_image_file,
                    GROUP_CONCAT(DISTINCT category.category_name ORDER BY category.category_name SEPARATOR ', ') as event_categories,
                    company.id AS company_id,
                    company.company_name,
                    COUNT(usuario.id) AS friends_quantity,
                    GROUP_CONCAT(DISTINCT usuario.name ORDER BY usuario.name SEPARATOR ', ') as friends_name,
                    IF (event.status = 2, event.cancel_reason, '') as cancel_reason,
                    event_interest.event_interest_name AS interest
                FROM eventy.event_follow
                    JOIN event ON event.id = event_follow.event_id AND `event`.`status` = 1
                    LEFT JOIN arquivos ON arquivos.referencia = event.id AND arquivos.tabela = 'event' AND arquivos.tipo = 'pri' AND arquivos.status = 1
                    JOIN event_category ON event_category.event_id = event.id
                    JOIN category ON category.id = event_category.category_id AND category.status = 1
                    JOIN company ON company.id = event.company_id
                    LEFT JOIN user_follow ON user_follow.user_id_follower = event_follow.user_id
                    LEFT JOIN event_follow friends ON friends.event_id = event.id AND friends.user_id = user_follow.user_id_followed
                    LEFT JOIN usuario ON usuario.id = friends.user_id
                    LEFT JOIN event_interest ON event_interest.id = event_follow.interest_id
                WHERE event_follow.user_id = ?
                    AND event_interest.positive
                    AND event.event_start_date >= \"".date('Y-m-01 H:i:s', $timestamp)."\"
                    AND event.event_start_date <= \"".date('Y-m-t H:i:s', $timestamp)."\"
                GROUP BY event.id
                ORDER BY event.event_start_date";

            $Database = new Database();
            $queryResult = $Database->query($sql, [$userId]);

            if ($queryResult === false)
                return [];

            $objsResult = array();
            foreach ($queryResult['result'] as $result) {
                $objsResult[] = new ModelEventListItem($result);
            }
            return $objsResult;
        }

        static function getUserEvents() {
            $sql = 
                "SELECT 
                    event.event_name as event_name,
                    event.id as event_id,
                    event.event_url as event_url,
                    event_start_date AS event_date,
                    arquivos.arquivo as event_image_file,
                    GROUP_CONCAT(DISTINCT category.category_name ORDER BY category.category_name SEPARATOR ', ') as event_categories,
                    company.id AS company_id,
                    company.company_name,
                    COUNT(usuario.id) AS friends_quantity,
                    GROUP_CONCAT(DISTINCT usuario.name ORDER BY usuario.name SEPARATOR ', ') as friends_name,
                    IF (event.status = 2, event.cancel_reason, '') as cancel_reason,
                    event_interest.event_interest_name AS interest
                FROM eventy.event_follow
                    JOIN event ON event.id = event_follow.event_id AND `event`.`status`
                    LEFT JOIN arquivos ON arquivos.referencia = event.id AND arquivos.tabela = 'event' AND arquivos.tipo = 'pri' AND arquivos.status = 1
                    JOIN event_category ON event_category.event_id = event.id
                    JOIN category ON category.id = event_category.category_id AND category.status = 1
                    JOIN company ON company.id = event.company_id
                    LEFT JOIN user_follow ON user_follow.user_id_follower = event_follow.user_id
                    LEFT JOIN event_follow friends ON friends.event_id = event.id AND friends.user_id = user_follow.user_id_followed
                    LEFT JOIN usuario ON usuario.id = friends.user_id
                    LEFT JOIN event_interest ON event_interest.id = event_follow.interest_id
                WHERE event_follow.user_id = ?
                    AND event.event_start_date >= NOW()
                    AND event_interest.positive
                GROUP BY event.id
                ORDER BY event.event_start_date";

                $Database = new Database();
                $queryResult = $Database->query($sql, [Session::getInfo('id')]);

                if ($queryResult === false)
                    return [];

                $objsResult = array();
                foreach ($queryResult['result'] as $result) {
                    $objsResult[] = new ModelEventListItem($result);
                }
                return $objsResult;
        }

        static function getRecomendedEvents($userId) {
            $Database = new Database();
            $Database->start();

            $sql = 
                'SELECT
                    a.event_name,
                    a.id as event_id,
                    a.event_url,
                    a.event_start_date AS event_date,
                    a.arquivo as event_image_file,
                    a.company_id,
                    a.company_name,
                    a.event_categories,
                    a.friends_name,
                    a.friends_quantity,
                    a.age_relevance + IFNULL(a.distance_relevance, 0) + a.category_relevance + a.sex_relevance AS relevance
                FROM (
                    SELECT 
                        (age >= min_age AND age <= max_age) * 100 AS age_relevance,
                        event.*
                    FROM (
                        SELECT 
                            ST_DISTANCE_SPHERE(event.address_coordinates, logged.address_coordinates) / 3000 AS distance_relevance,
                            COUNT(DISTINCT interest_categories.id) / COUNT(DISTINCT user_category.id) * 200 AS category_relevance,
                            ((event.to_male AND logged.sex = "M") OR (event.to_female AND logged.sex = "F")) * 100 AS sex_relevance,
                            
                            event.id, 
                            event.event_name, 
                            event.event_url,
                            arquivos.arquivo,
                            event.cancel_reason,
                            event.status,
                            event.event_start_date,
                            
                            /* Need this to calculate age relevance */
                            event.max_age,
                            event.min_age,
                            YEAR(CURRENT_TIMESTAMP) - YEAR(logged.birthdate) - (RIGHT(CURRENT_TIMESTAMP, 5) < RIGHT(logged.birthdate, 5)) as age,

                            company.id AS company_id,
                            company.company_name,

                            GROUP_CONCAT(DISTINCT category.category_name ORDER BY category.category_name SEPARATOR ", ") as event_categories,

                            GROUP_CONCAT(DISTINCT usuario.name ORDER BY usuario.name SEPARATOR ", ") as friends_name,
                            COUNT(usuario.id) AS friends_quantity
                        FROM
                            event
                            /* Need to calculate distance relevance */
                            INNER JOIN usuario logged ON logged.id = ?
                            
                            /* Need to get event image */
                            LEFT JOIN arquivos ON arquivos.referencia = event.id
                                AND arquivos.tabela = "event"
                                AND arquivos.status = 1
                                
                            /* Need to calculate category relevance */
                            LEFT JOIN event_category ON event_category.event_id = event.id
                            LEFT JOIN category ON category.id = event_category.category_id
                                AND category.status = 1
                            LEFT JOIN user_category ON user_category.user_id = logged.id
                            LEFT JOIN user_category interest_categories ON interest_categories.user_id = logged.id
                                AND interest_categories.category_id = event_category.category_id

                            JOIN company ON company.id = event.company_id

                            LEFT JOIN user_follow ON user_follow.user_id_follower = logged.id
                            LEFT JOIN event_follow friends ON friends.event_id = event.id AND friends.user_id = user_follow.user_id_followed
                            LEFT JOIN usuario ON usuario.id = friends.user_id
                        WHERE
                            event.status = 1
                            AND event.event_privacity = 2
                            AND event.event_start_date >= NOW()
                        GROUP BY event.id
                    ) event
                ) a
                ORDER BY relevance IS NULL, relevance > 0, relevance DESC
                LIMIT 15';

            $args = [$userId];

            $queryResult = $Database->query($sql, $args);
            $Database->kill();
            
            if ($queryResult === false)
                return [];

            $objsResult = array();
            foreach ($queryResult['result'] as $result) {
                $objsResult[] = new ModelEventListItem($result);
            }
            return $objsResult;
        }

        static function smartSearch($string, $page) {
            $Database = new Database();
            $Database->start();

            $sql = 'SET @row_number:=0';
            $Database->query($sql);

            $sql = 
                'SELECT
                    a.id,
                    a.event_name,
                    a.event_url,
                    a.arquivo,
                    a.cancel_reason,
                    a.status,
                    IF(a.search_relevance < 0, 0, a.search_relevance) + a.age_relevance + a.distance_relevance + a.category_relevance + a.sex_relevance AS relevance
                FROM (
                    SELECT 
                        @row_number:=@row_number+1 AS row_number,
                        100 - POW(1.047128, @row_number) AS search_relevance,
                        (age >= min_age AND age <= max_age) * 100 AS age_relevance,
                        event.*
                    FROM (
                        SELECT 
                            ST_DISTANCE_SPHERE(event.address_coordinates, logged.address_coordinates) / 3000 AS distance_relevance,
                            COUNT(DISTINCT interest_categories.id) / COUNT(DISTINCT user_category.id) * 200 AS category_relevance,
                            ((event.to_male AND logged.sex = "M") OR (event.to_female AND logged.sex = "F")) * 100 AS sex_relevance,
                            
                            event.id, 
                            event.event_name, 
                            event.event_url,
                            arquivos.arquivo,
                            event.cancel_reason,
                            event.status,
                            
                            /* Need this to calculate age relevance */
                            event.max_age,
                            event.min_age,
                            YEAR(CURRENT_TIMESTAMP) - YEAR(logged.birthdate) - (RIGHT(CURRENT_TIMESTAMP, 5) < RIGHT(logged.birthdate, 5)) as age
                        FROM
                            event
                            /* Need to calculate distance relevance */
                            INNER JOIN usuario logged ON logged.id = ?
                            
                            /* Need to get event image */
                            LEFT JOIN arquivos ON arquivos.referencia = event.id
                                AND arquivos.tabela = "event"
                                AND arquivos.status = 1
                                
                            /* Need to calculate category relevance */
                            LEFT JOIN event_category ON event_category.event_id = event.id
                            LEFT JOIN category ON category.id = event_category.category_id
                                AND category.status = 1
                            LEFT JOIN user_category ON user_category.user_id = logged.id
                            LEFT JOIN user_category interest_categories ON interest_categories.user_id = logged.id
                                AND interest_categories.category_id = event_category.category_id
                        WHERE
                            MATCH (event_name, event_url, event_description) AGAINST (?)
                            AND event.status IN (1, 2)
                        GROUP BY event.id
                    ) event
                ) a
                ORDER BY relevance IS NULL, relevance > 0, relevance DESC
                LIMIT 5 OFFSET ' . ($page * 5);

            $args = [Session::getInfo('id'), $string];

            $queryResult = $Database->query($sql, $args);
            $Database->kill();
            
            if ($queryResult === false)
                return [];

            $objsResult = array();
            foreach ($queryResult['result'] as $result) {
                $objsResult[] = new ModelEventListItem($result);
            }
            return $objsResult;
        }
    }
?>