<?php
	function getClasses(){
        $classes = func_get_args();
        
        foreach ($classes as $class)
            require_once(CLASS_PATH.$class.'.php');
    }

	function getControl(){
        $controllers = func_get_args();
        
        foreach ($controllers as $control)
            require_once(CONTROL_PATH.$control.'.php');
    }

	function getTraits(){
        $traits = func_get_args();
        
        foreach ($traits as $trait)
            require_once(TRAIT_PATH.$trait.'.php');
    }

    function requireAll() {
        $classes = scandir(CLASS_PATH);
        $traits = scandir(TRAIT_PATH);
        $models = scandir(MODEL_PATH);
        $controls = scandir(CONTROL_PATH);

        foreach ($classes as $file) {
            if (is_file(CLASS_PATH.$file))
                require_once(CLASS_PATH.$file);
        }

        foreach ($traits as $file) {
            if (is_file(TRAIT_PATH.$file))
                require_once(TRAIT_PATH.$file);
        }

        foreach ($models as $file) {
            if (is_file(MODEL_PATH.$file))
                require_once(MODEL_PATH.$file);
        }

        foreach ($controls as $file) {
            if (is_file(CONTROL_PATH.$file))
                require_once(CONTROL_PATH.$file);
        }
    }

    function includePage() {
        global $referencia, $tipo, $pagina, $subpagina, $url;

        $arquivo = $tipo.'/'.$pagina.'.php';
        if (file_exists($arquivo)) {
            ob_start();
            try {
                require($arquivo);
			} catch (Exception $e) {
                ob_clean();
				getErrorPage(500, $e);
			} catch (Throwable $t) {
                ob_clean();
                getErrorPage(500, $t);
            }
        } else {
            getErrorPage(404);
        }
        
    }

    function getErrorPage($errorCode, $e = null) {
        http_response_code($errorCode);
        include('html/'.$errorCode.'.php');
    }

    function debug_log() {
        @error_log(
            date('Y-m-d H:i:s')."\n"
            .var_export(func_get_args(), true)."\n"
            .$_SERVER['REQUEST_URI']."\n\n"
        , 3, ROOT_PATH.'debug.log');
    }

    function necessitaLogin() {
        if (Session::isLogged())
            return false;
        
        if (Session::isAdmin()) {
            include(ADMIN_PATH . 'html/login.php');
        } else {
            include(ROOT_PATH . 'html/login.php');
        }

        return true;
    }

    function validaCNPJ($cnpj) {
        $cnpj = preg_replace('/[^0-9]/', '', (string) $cnpj);
        // Valida tamanho
        if (strlen($cnpj) != 14)
            return false;
        // Valida primeiro dígito verificador
        for ($i = 0, $j = 5, $soma = 0; $i < 12; $i++) {
            $soma += $cnpj{$i} * $j;
            $j = ($j == 2) ? 9 : $j - 1;
        }
        $resto = $soma % 11;
        if ($cnpj{12} != ($resto < 2 ? 0 : 11 - $resto))
            return false;
        // Valida segundo dígito verificador
        for ($i = 0, $j = 6, $soma = 0; $i < 13; $i++) {
            $soma += $cnpj{$i} * $j;
            $j = ($j == 2) ? 9 : $j - 1;
        }
        $resto = $soma % 11;
        return $cnpj{13} == ($resto < 2 ? 0 : 11 - $resto);
    }

    function necessitaLoginAjax() {
        if (!Session::isLogged()) {
            http_response_code(401);
            Response::message('Faça o login', Response::ERROR);
            Response::status(false);
            Response::print();
            die();
        }
    }

    function unique_code($limit) {
        return substr(base_convert(sha1(uniqid(mt_rand())), 16, 36), 0, $limit);
    }

    function soNumeros($string) {
        return preg_replace('/[^0-9]/', '', $string);;
    }
?>
