<?php 

    if (Session::isLogged()) {
        @list($UserRating) = EventRating::getBy(array(
            'event_id'  => $Evento->id,
            'user_id'   => Session::getInfo('id')
        ));

        @list($Denuncia) = EventReport::getBy(array(
            'event_id' => $Evento->id,
            'user_id'    => Session::getInfo('id')
        ));

        $Ratings = EventRating::getRatingsFromBy($Evento->id, Session::getInfo('id'));
        $rate = $UserRating ? $UserRating->event_rating_rate : 1;

        $Invites = EventInvite::getBy([
            EventInvite::_TABLE.".event_id"  => $Evento->id,
            EventInvite::_TABLE.".user_id_invited"   => Session::getInfo('id')
        ], array(EventInvite::_TABLE.".*", User::_TABLE.".name AS user_name", Archive::_TABLE.'.arquivo'), false, [
            User::_TABLE => [
                User::_TABLE.".id" => EventInvite::_TABLE.".user_id_inviter"
            ]
        ], [
            Archive::_TABLE => [
                Archive::_TABLE . '.referencia' => User::_TABLE . '.id',
                Archive::_TABLE . '.tabela' => '"'.User::_TABLE.'"',
                Archive::_TABLE . '.tipo' => '"pri"',
                Archive::_TABLE . '.status' => 1
            ]
        ]);
    } else {
        $Ratings = EventRating::getRatingsFromBy($Evento->id, 0);
        $rate = 1;
        $Invites = [];
    }

    if (strlen($Evento->event_name) <= 20) {
        $titleSizeClass = 'tiny-title';
    } else if (strlen($Evento->event_name) <= 50) {
        $titleSizeClass = 'small-title';
    } else if (strlen($Evento->event_name) <= 150) {
        $titleSizeClass = 'medium-title';
    } else {
        $titleSizeClass = 'large-title';
    }

    $Images = Archive::getBy(array(
        'tabela'    => Event::_TABLE,
        'tipo'      => 'pri',
        'referencia'=> $Evento->id,
        'status'    => 1
    ));

    $AverageRating = EventRating::averageRating($Evento->id);

    @list($FollowStatus) = EventFollow::getBy([
        'event_id'  => $Evento->id,
        'user_id'   => Session::getInfo('id')
    ]);

    $FriendsFollowing = EventFollow::getFriends($Evento->id, Session::getInfo('id'));

    $Follows = UserFollow::getBy([
        UserFollow::_TABLE . '.user_id_followed'   => Session::getInfo('id')
    ], [
        UserFollow::_TABLE . '.*',
       User::_TABLE . '.name'
    ], false, [
       User::_TABLE => [
            UserFollow::_TABLE . '.user_id_follower' =>User::_TABLE . '.id'
        ]
    ]);

    $listaPublicacoes = $Evento->getPublications(0);
    $listaMencoes = $Evento->getUserMentions();

    $interestId = $FollowStatus ? @$FollowStatus->interest_id : 0;

    $pastEvent = ($Evento->event_start_date)('Ymd') < date('Ymd');

    LogUser::insert([
        'user_id'       => Session::getInfo('id'),
        'log_action'    => 'view_screen',
        'log_file'      => __FILE__,
        'log_success'   => true
    ]);
?>
<div class="content center-align" id="events">
    <div class="header">
        <div class="container title row">
            <div class="col s12 m2 l1">
                <table class="calendar">
                    <thead>
                        <tr class="red white-text">
                            <td class="center-align"><?=$Evento->event_start_date->toMonthInitials()?></td>
                        </tr>
                    </thead>
                    <tbody>
                        <tr>
                            <td class="center-align"><?=($Evento->event_start_date)('d')?></td>
                        </tr>
                    </tbody>
                </table>
            </div>
            <div class="col s12 m10 l11">
                <h1 class="left-align <?=$titleSizeClass?> center">
                    <?=$Evento->event_name?>
                </h1>
            </div>
        </div>
    </div>

    <div class="body">
        <div class="container">
            <div class="row">
                
                <?php if ($Evento->status == 2) : ?>
                    <div class="col s12 justify info-box" id="cancel-reason">
                        <i class="icon-cancel-circle left"></i>
                        <div class="content-info">
                            <?=nl2br($Evento->cancel_reason)?>
                        </div>
                    </div>
                <?php endif ?>

                <!-- Convites -->
                <?php if ($Invites) : ?>
                    <div class="col s12 left-align grey-text" id="invites-title">
                        Pessoas que te convidaram
                    </div>
                    <div class="col s12 left-align">
                        <div class="carousel">
                            <?php foreach ($Invites as $Invite) : ?>
                                <a class="carousel-item inviter" href="<?=SITE_URL . 'perfil/' . $Invite->user_id_inviter?>">
                                    <img src="<?=($Invite->arquivo ? IMG_PATH . 'dinamicas/usuario/' . $Invite->user_id_inviter . '/pri/pp' . $Invite->arquivo : NO_IMAGE)?>" class="circle">
                                    <b class="truncate"><?=$Invite->user_name?></b>
                                </a>
                            <?php endforeach ?>
                        </div>
                    </div>
                <?php endif ?>
                <!-- END Convites -->

                <!-- Botões de Ações -->
                <?php if (!$pastEvent) : ?>
                    <div class="col s12 right-align">
                        <?php if (Session::isLogged()) : ?>
                            <?php if (!$Denuncia) : ?>
                                <a class="report main-color-text tooltipped clickable" data-tooltip="Denunciar"><i class="icon-report large-size"></i></a> 
                            <?php endif ?>
                            <?php if ($Evento->event_privacity == 1) : ?>
                                <?php if ($Invites || $isDono) : ?>
                                    <a href="#participate" class="participate main-color-text tooltipped clickable modal-trigger" data-tooltip="Participar"><i class="icon-vote large-size"></i></a>
                                    <?php if ($Follows) : ?>
                                        <a href="#invite" class="invite main-color-text tooltipped clickable modal-trigger" data-tooltip="Convidar"><i class="icon-user-plus large-size"></i></a>
                                    <?php endif ?>
                                <?php else : ?>
                                    <a class="grey-text tooltipped clickable" data-tooltip="Você precisa de um convite para participar desse evento"><i class="icon-vote large-size"></i></a>
                                <?php endif ?>
                            <?php else : ?>
                                <a href="#participate" class="participate main-color-text tooltipped clickable modal-trigger" data-tooltip="Participar"><i class="icon-vote large-size"></i></a>
                            <?php endif ?>
                            <a href="<?=$Evento->getUrl()?>/interessados" class="participate main-color-text tooltipped clickable modal-trigger" data-tooltip="Interessados"><i class="icon-users large-size"></i></a>
                            <?php if ($isDono) : ?>
                                <a href="#publication" class="main-color-text tooltipped clickable modal-trigger" data-tooltip="Publicar"><i class="icon-publication large-size"></i></a>
                                <a href="javascript:void(0)" class="main-color-text tooltipped clickable cancel-event" data-tooltip="Cancelar"><i class="icon-remove large-size red-text"></i></a>
                            <?php endif ?>
                        <?php endif ?>
                        <br><br>
                    </div>
                <?php endif ?>
                <!-- END Botões de Ações -->

                <!-- Informações -->
                <div class="col s12 m8 grey-text left-align">
                    Feito por <a href="<?=$Empresa->getUrl()?>"><?=$Empresa->company_name?></a>
                </div>
                <div class="col s12 m4 grey-text">
                    <b><?=$Evento->event_value->isEmpty() ? $Evento->event_value->beutify() : 'Grátis'?></b>
                </div>
                <div class="col s12 m2 grey-text">
                    <b>De:</b> <?=($Evento->event_start_date)('d/m/Y')?><br>
                    <b>Até:</b> <?=($Evento->event_end_date)('d/m/Y')?>
                </div>
                <div class="col s12 m4 grey-text">
                    <b>Horário:</b> <?=($Evento->event_start_date)('H:i')?> - <?=($Evento->event_end_date)('H:i')?>
                </div>
                <div class="col s12 grey-text">
                    <b>Local:</b> <?=$Evento->printEndereco()?>
                </div>
                <!-- END Informações -->

                <!-- Imagens -->
                <?php if ($Images) : ?>
                    <div class="col s12 slider">
                        <ul class="slides">
                            <?php foreach ($Images as $Image) : ?>
                                <li>
                                    <img src="<?=$Image->getUrl('m')?>" alt="<?=$Image->titulo?>">
                                    <div class="caption center-align <?=(!$Image->titulo && !$Image->descricao ? 'empty' : '')?>">
                                        <h3><?=$Image->titulo?></h3>
                                        <h5 class="light grey-text text-lighten-3"><?=$Image->descricao?></h5>
                                    </div>
                                </li>
                            <?php endforeach ?>
                        </ul>
                        <?php if ($Evento->status == 2) : ?>
                            <div class="cancelled-flag">CANCELADO</div>
                        <?php endif ?>
                    </div>
                <?php endif ?>
                <!-- END Imagens -->

                <div class="col s12 justify" id="event-description">
                    <div id="event-description-text"><?=nl2br($Evento->event_description)?></div>
                </div>

                <!-- Amigos -->
                <?php if ($FriendsFollowing) : ?>
                    <div class="col s12 left-align grey-text" id="friends-title">
                        Essas pessoas pretendem comparecer
                    </div>
                    <div class="col s12 left-align">
                        <div class="carousel">
                            <?php foreach ($FriendsFollowing as $Friend) : ?>
                                <a class="carousel-item inviter" href="<?=SITE_URL . 'perfil/' . $Friend['user_id']?>">
                                    <img src="<?=($Friend['arquivo'] ? IMG_PATH . 'dinamicas/usuario/' . $Friend['user_id'] . '/pri/pp' . $Friend['arquivo'] : NO_IMAGE)?>" class="circle">
                                    <b class="truncate"><?=$Friend['user_name']?></b>
                                </a>
                            <?php endforeach ?>
                        </div>
                    </div>
                <?php endif ?>
                <!-- END Amigos -->

                <!-- Event Publications -->
                <?php if ($listaPublicacoes) : ?>
                    <div class="col s12 m8 offset-m2 title bottom-divider left-align">
                        <h4 class="truncate">
                            Publicações
                        </h4>
                    </div>
                    <div class="col s12 center-align" id="activities-container">
                        <?php foreach ($listaPublicacoes as $Publicacao) : ?>
                            <div class="card large" data-id="<?=$Publicacao->id?>">
                                <form class="hide" action="<?=SITE_URL?>evento" data-success-callback="$('div.card[data-id=<?=$Publicacao->id?>]').remove()">
                                    <input type="hidden" name="type" value="deletePublication">
                                    <input type="hidden" name="id" value="<?=$Publicacao->id?>">
                                </form>
                                <div class="card-image">
                                    <?php if ($Publicacao->arquivo) : ?>
                                        <img src="<?=IMG_PATH?>dinamicas/event_publication/<?=$Publicacao->id?>/pri/p<?=$Publicacao->arquivo?>" class="publication-img">
                                    <?php else : ?>
                                        <img src="<?=NO_IMAGE?>" class="publication-img">
                                    <?php endif ?>
                                    <?php if ($isDono) : ?>
                                        <i class="icon-trash circle white-text publication-button tooltipped center-align clickable delete-publication" data-tooltip="Deletar"></i>
                                    <?php endif ?>
                                </div>
                                <?php if ($Publicacao->text) : ?>
                                    <div class="card-content">
                                        <p><?=$Publicacao->text?></p>
                                    </div>
                                <?php endif ?>
                                <p class="publication-date right-align grey-text"><?=$Publicacao->date?></p>
                            </div>
                        <?php endforeach ?>
                    </div>
                    <div class="col s12" id="bottom-loading"></div>
                <?php endif ?>
                <!-- END Event Publications -->

                <!-- User Publications -->
                <?php if ($listaMencoes) : ?>
                    <div class="col s12 m8 offset-m2 title bottom-divider left-align">
                        <h4 class="truncate">
                            Menções
                        </h4>
                    </div>
                    <div class="col s12 slider mencoes">
                        <ul class="slides">
                            <?php foreach ($listaMencoes as $Publicacao) : ?>
                                <li>
                                    <div class="card large">
                                        <div class="card-image">
                                            <?php if ($Publicacao->arquivo) : ?>
                                                <img src="<?=IMG_PATH?>dinamicas/user_publication/<?=$Publicacao->id?>/pri/p<?=$Publicacao->arquivo?>" class="publication-img">
                                            <?php else : ?>
                                                <img src="<?=NO_IMAGE?>" class="publication-img">
                                            <?php endif ?>
                                        </div>
                                        <?php if ($Publicacao->text) : ?>
                                            <div class="card-content">
                                                <p><?=$Publicacao->text?></p>
                                            </div>
                                        <?php endif ?>
                                        <p class="publication-date right-align grey-text"><?=$Publicacao->date?></p>
                                    </div>
                                </li>
                            <?php endforeach ?>
                        </ul>
                    </div>
                <?php endif ?>
                <!-- END User Publications -->

                <?php if ($Ratings) : ?>
                    <div class="col s12 left-align" id="comment-title">
                        Comentários
                    </div>
                <?php endif ?>

                <?php if ($AverageRating['quantity'] >= 3) : ?>
                    <!-- Average Rating -->
                    <div class="col s12 m4" id="rating"><?=number_format($AverageRating['average'], 1, '.', '')?></div>
                    <div class="col s12 m8" id="rating-div">
                        <?php 
                            $whole = floor((float)$AverageRating['average']);
                            $fraction = (float)$AverageRating['average'] - $whole;
                        ?>
                        <div class="yellow-text text-darken-2 rating-stars">
                            <?php for ($i = 1; $i <= 5; $i++) : ?>
                                <?php if ((float)$AverageRating['average'] >= $i) { ?>
                                    <i class="icon-star-full"></i>
                                <?php } else if ($fraction < 0.25) { $fraction = 0; ?>
                                    <i class="icon-star-empty"></i>
                                <?php } else if ($fraction <= 0.75) { $fraction = 0; ?>
                                    <i class="icon-star-half"></i>
                                <?php } else if ($fraction > 0.75) { $fraction = 0; ?>
                                    <i class="icon-star-full"></i>
                                <?php } else { ?>
                                    <i class="icon-star-empty"></i>
                                <?php } ?>
                            <?php endfor ?>
                            <br>
                            <span class="black-text">Média de <?=number_format((float)$AverageRating['average'], 1, '.', '')?> baseado em <?=$AverageRating['quantity']?> avaliações</span>
                        </div>
                    </div>
                    <!-- End of Average Rating -->
                <?php endif ?>

                <!-- Comments -->
                <div class="col s12" id="comment-list">
                    <!-- Other Comments -->
                    <?php foreach ($Ratings as $Rating) : ?>
                        <div class="row comment">
                            <div class="col s2">
                                <img src="/tcc/assets/images<?=$Rating->foto?>" class="circle">
                                <b class="truncate"><?=$Rating->user_name?></b>
                            </div>
                            <div class="col s10 left-align">
                                <?php for ($i = 1; $i <= 5; $i++) : ?>
                                    <?php if ((float)$Rating->event_rating_rate >= $i) { ?>
                                        <i class="icon-star-full yellow-text"></i>
                                    <?php } else { ?>
                                        <i class="icon-star-empty yellow-text"></i>
                                    <?php } ?>
                                <?php endfor ?>
                                <br>
                                <?=$Rating->event_rating_commentary?>
                            </div>
                        </div>
                    <?php endforeach ?>
                    <!-- End Other Comments -->
                    <!-- Your Comment -->
                    <?php if ((($Evento->event_privacity == 1 && $Invites) || $Evento->event_privacity == 2) && (!$pastEvent || $interestId)) : ?>
                        <?php if (!Session::is($Empresa->user_id)) : ?>
                            <?php if (Session::isLogged()) : ?>
                                <?php if (@$UserRating->status === "1" || !@$UserRating) : ?>
                                    <div class="col s12 left-align" id="your-comment-title">
                                        Seu Comentário
                                    </div>
                                    <div class="row your-comment">
                                        <div class="col s2">
                                            <img src="<?=Session::getInfo('photo')?>" class="circle">
                                            <b class="truncate"><?=Session::getInfo('name')?></b>
                                        </div>
                                        <div class="col s10 left-align">
                                            <?php for ($i = 1; $i <= 5; $i++) : ?>
                                                <?php if ((float)$rate >= $i) { ?>
                                                    <i class="icon-star-full clickable yellow-text text-darken-2 large-size" data-star="<?=$i?>"></i>
                                                <?php } else { ?>
                                                    <i class="icon-star-empty clickable yellow-text text-darken-2 large-size" data-star="<?=$i?>"></i>
                                                <?php } ?>
                                            <?php endfor ?>
                                            <br>
                                            <form id="comentario" action="<?=SITE_URL?>evento" data-success-callback="location.reload()">
                                                <input type="hidden" id="ratingComment" name="dados[nota]" value="<?=$rate?>"> 
                                                <input type="hidden" name="type" value="comment">
                                                <input type="hidden" name="dados[evento]" value="<?=$Evento->id?>">
                                                <textarea class="materialize-textarea" name="dados[comentario]"><?=($UserRating ? $UserRating->event_rating_commentary : '')?></textarea>
                                                <button class="btn main-color darken-1 right">Avaliar</button>
                                            </form>
                                        </div>
                                    </div>
                                <?php else : ?>
                                    <div class="col s12 left-align" id="your-comment-title">
                                        Seu Comentário
                                    </div>
                                    <div class="col s12 m2">
                                        <i class="icon-info grey-text biggest-size"></i>
                                    </div>
                                    <div class="col s12 m10 left-align valign-wrapper grey-text" style="height: 70px;">
                                        Seu comentário foi bloqueado para esse evento!
                                    </div>
                                <?php endif ?>
                            <?php endif ?>
                        <?php endif ?>
                    <?php endif ?>
                    <!-- End Your Comment -->
                </div>
                <!-- End Comments -->
            </div>
        </div>
    </div>
</div>

<!-- Modal Structure -->
<form id="participate" class="modal" action="<?=SITE_URL?>evento" data-success-callback="location.reload()">
    <input type="hidden" name="type" value="follow">
    <input type="hidden" name="dados[evento]" value="<?=$Evento->id?>">

    <div class="modal-content">
        <h4>Participação</h4>
        <div class="row">
            <div class="input-field col s12">
                <select name="dados[participacao]">
                    <option value="1" <?=$interestId == 1 ? 'selected' : ''?>>Tenho Interesse</option>
                    <option value="2" <?=$interestId == 2 ? 'selected' : ''?>>Comparecerei</option>
                    <option value="3" <?=$interestId == 3 ? 'selected' : ''?>>Não Vou</option>
                </select>
            </div>
        </div>
    </div> 
    <div class="modal-footer">
        <a href="#!" class="modal-action modal-close waves-effect waves-green btn-flat">Cancelar</a>
        <button type="submit" class="modal-action waves-effect waves-green btn small">Salvar</button>
    </div>
</form>

<form id="publication" class="modal" action="<?=SITE_URL?>evento" data-success-callback="location.reload()" enctype="multipart/form-data">
    <input type="hidden" name="type" value="publication">
    <input type="hidden" name="dados[evento]" value="<?=$Evento->id?>">
    <input type="file" name="photo" class="hide">

    <div class="modal-content">
        <h4>Publicar</h4>
        <div class="row">
            <div class="col s12 center">
                <img src="<?=IMG_PATH?>add_photo.svg" id="pub-image" class="clickable">
            </div>
            <div class="input-field col s12">
                <input type="text" id="pub_text" name="texto" maxlenght="255">
                <label for="pub_text">
                    Escreva algo
                </label>
            </div>
        </div>
    </div>
    <div class="modal-footer">
        <a href="#!" class="modal-action modal-close waves-effect waves-green btn-flat">Cancelar</a>
        <button type="submit" class="modal-action waves-effect waves-green btn small">Publicar</button>
    </div>
</form>

<form id="invite" class="modal" action="<?=SITE_URL?>evento" data-success-callback="">
    <input type="hidden" name="type" value="invite">
    <input type="hidden" name="dados[evento]" value="<?=$Evento->id?>">

    <div class="modal-content">
        <h4>Convidar Amigo</h4>
        <div class="row">
            <div class="input-field col s12">
                <select name="dados[convidado]">
                    <?php foreach ($Follows as $Follow) : ?>
                        <option value="<?=$Follow->user_id_follower?>"><?=$Follow->name?></option>
                    <?php endforeach ?>
                </select>
            </div>
        </div>
    </div>
    <div class="modal-footer">
        <a href="#!" class="modal-action modal-close waves-effect waves-green btn-flat">Cancelar</a>
        <button type="submit" class="modal-action modal-close waves-effect waves-green btn small main-color">Convidar</button>
    </div>
</form>

<script type="text/javascript">
    var currentId = '<?=$referencia?>';
</script>