<?php
    class ModelEvent {
        use Model {
            __construct as protected constructor;
        }

        var $id, 
            $event_name, 
            $event_description, 
            $event_url, 
            $event_value, 
            $event_start_date,
            $address_postal_code,
            $city_id,
            $address_neightborhood,
            $address_number,
            $address_complement,
            $address_street,
            $address_coordinates,
            $company_id,
            $event_privacity,
            $min_age,
            $max_age,
            $to_male,
            $to_female,
            $cancel_reason,
            $date_cancel,
            $date_insert,
            $date_update;

        const _require = array('event_name');
        const _key = array('id');
        const _filters = array(
                'event_value'           => 'Money', 
                'event_start_date'      => 'TimeDate',
                'event_end_date'        => 'TimeDate',
                'date_update'           => 'TimeDate',
                'date_cancel'           => 'TimeDate',
                'date_insert'           => 'TimeDate',
                'address_number'        => 'Int',
                'event_privacity'       => 'Int',
                'min_age'               => 'Int',
                'max_age'               => 'Int',
                'address_coordinates'   => 'Point'
        );
        const _not_empty = array(
            'id', 
            'address_coordinates', 
            'cancel_reason', 
            'min_age', 
            'max_age', 
            'to_male', 
            'to_female', 
            'date_update', 
            'date_cancel', 
            'date_insert'
        );

        function __construct($campos) {
            $this->event_start_date = new TimeDate(NULL);
            $this->event_end_date = new TimeDate(NULL);
            $this->date_update = new TimeDate(NULL);
            $this->date_insert = new TimeDate(NULL);
            $this->date_cancel = new TimeDate(NULL);

            $this->date_update->format = 'd/m/Y H:i';
            $this->date_insert->format = 'Y-m-d H:i:s';
            $this->constructor($campos);
        }
        
        /*
        * @param array
        *   %C = Cidade
        *   %U = Estado
        *   %B = Bairro
        *   %R = Logradouro
        *   %N = Número
        *   %E = Complemento
        */
        function printEndereco($format = '%C, %U - %B %R, %N %E') {
            @list($City) = City::getBy(['id' => $this->city_id]);
            @list($State) = State::getBy(['id' => $City->state_id]);
            $endereco = str_ireplace('%C', $City->name, $format);
            $endereco = str_ireplace('%U', $State->uf, $endereco);
            $endereco = str_ireplace('%B', $this->address_neightborhood, $endereco);
            $endereco = str_ireplace('%R', $this->address_street, $endereco);
            $endereco = str_ireplace('%N', $this->address_number, $endereco);
            $endereco = str_ireplace('%E', $this->address_complement, $endereco);

            return $endereco;
        }

        function getUrl() {
            return SITE_URL.'evento/'. $this->event_url;
        }

        function calculateCoordinates() {
            $address = $this->printEndereco('%R, %N - %B, %C - %U');
            $url = 'https://maps.googleapis.com/maps/api/geocode/json?address='.urlencode($address).'&key=' . GOOGLE_MAPS_KEY;

            $curl = curl_init();

            curl_setopt($curl, CURLOPT_URL, $url);
            curl_setopt($curl, CURLOPT_RETURNTRANSFER, true); 

            $response = curl_exec($curl);
            $status = curl_getinfo($curl,CURLINFO_HTTP_CODE);
            curl_close($curl);

            $jsonResponse = json_decode($response);

            if (!$jsonResponse)
                return null;

            if ($jsonResponse->status !== 'OK')
                return null;
            
            return new Point($jsonResponse->results[0]->geometry->location->lat, $jsonResponse->results[0]->geometry->location->lng);
        }

        function getPublications($page = 0) {
            return EventPublication::getBy([
                EventPublication::_TABLE . '.event_id'  => $this->id,
                EventPublication::_TABLE . '.status'    => 1
            ], [
                EventPublication::_TABLE . '.id',
                EventPublication::_TABLE . '.event_id',
                EventPublication::_TABLE . '.text',
                EventPublication::_TABLE . '.date',
                Archive::_TABLE . '.arquivo'
            ], false, [
                Archive::_TABLE => [
                    Archive::_TABLE . '.tabela'    => '"'.EventPublication::_TABLE.'"',
                    Archive::_TABLE . '.tipo'      => '"pri"',
                    Archive::_TABLE . '.referencia'=> EventPublication::_TABLE . '.id',
                    Archive::_TABLE . '.status'    => 1
                ]
            ], [], false, false, EventPublication::_TABLE . '.date DESC', ($page * 5).', 5');
        }

        function getUserMentions() {
            return Event::getBy([
                Event::_TABLE.'.status' => 1,
                Event::_TABLE.'.id' => $this->id
            ], [
                User::_TABLE . '.id AS user_id',
                User::_TABLE . '.name as user_name',
                Archive::_TABLE . '.arquivo',
                UserPublication::_TABLE . '.date',
                UserPublication::_TABLE . '.text',
                UserPublication::_TABLE . '.id'
            ], false, [
                UserPublication::_TABLE => [
                    UserPublication::_TABLE . '.event_id' => Event::_TABLE.'.id',
                    UserPublication::_TABLE . '.status' => 1
                ],
                User::_TABLE => [
                    User::_TABLE . '.id' => UserPublication::_TABLE . '.user_id',
                    User::_TABLE . '.status' => 1
                ],
                Archive::_TABLE => [
                    Archive::_TABLE . '.tabela'     => '"'.UserPublication::_TABLE.'"',
                    Archive::_TABLE . '.tipo'       => '"pri"',
                    Archive::_TABLE . '.referencia' => UserPublication::_TABLE . '.id',
                    Archive::_TABLE . '.status'     => 1
                ]
                ], [], [], [], 'RAND()', 10);
        }
    }

?>