<?php 
    class ModelUser {
        use Model;

        var $id, 
            $name, 
            $email,
            $password, 
            $birthdate,
            $sex,
            $address_postal_code,
            $city_id,
            $address_neightborhood,
            $address_street,
            $address_number,
            $address_coordinates;

        const _require = array('name', 'email');
        const _key = array('id');
        const _filters = array(
                'email'                 => 'Mail',
                'address_coordinates'   => 'Point',
                'birthdate'             => 'Date'
        );
        const _not_empty = array(
            'password', 
            'sex',
            'email',
            'id',
            'address_coordinates',
            'birthdate',
            'city_id'
        );

        function getFeed($page) {
            $sql =
                '(SELECT 
                    user_publication.id,
                    user_publication.user_id,
                    user_publication.event_id,
                    user_publication.text,
                    user_publication.date,
                    arquivos.arquivo,
                    event.event_name,
                    "user_publication" AS activity_type,
                    0 AS rating,
                    event.event_url
                FROM
                    user_publication
                    INNER JOIN arquivos ON arquivos.tabela = "user_publication"
                        AND arquivos.referencia = user_publication.id
                        AND arquivos.tipo = "pri"
                    LEFT JOIN event ON event.id = user_publication.event_id
                        AND event.status = 1
                WHERE
                    user_publication.user_id = ?
                    AND user_publication.status = 1
                ORDER BY user_publication.date DESC)
                
                UNION
                
                (SELECT 
                    event_follow.id,
                    event_follow.user_id,
                    event_follow.event_id,
                    CONCAT("<b>Marcou participação: </b>", event_interest.event_interest_name) AS text,
                    event_follow.date,
                    arquivos.arquivo,
                    event.event_name,
                    "event_follow" AS activity_type,
                    0 AS rating,
                    event.event_url
                FROM
                    event_follow
                    INNER JOIN event ON event.id = event_follow.event_id
                        AND event.status = 1
                    LEFT JOIN arquivos ON arquivos.tabela = "event"
                        AND arquivos.referencia = event.id
                        AND arquivos.tipo = "pri"
                        AND arquivos.status = 1
                    JOIN event_interest ON event_interest.id = event_follow.interest_id
                WHERE
                    event_follow.user_id = ?
                GROUP BY event_follow.id
                ORDER BY event_follow.date DESC)
                
                UNION
                
                (SELECT 
                    event_rating.id,
                    event_rating.user_id,
                    event_rating.event_id,
                    CONCAT("<b>Comentou no evento: </b>", event_rating.event_rating_commentary) AS text,
                    event_rating.date,
                    arquivos.arquivo,
                    event.event_name,
                    "event_rating" AS activity_type,
                    event_rating.event_rating_rate AS rating,
                    event.event_url
                FROM
                    event_rating
                    INNER JOIN event ON event.id = event_rating.event_id
                        AND event.status = 1
                    LEFT JOIN arquivos ON arquivos.tabela = "event"
                        AND arquivos.referencia = event.id
                        AND arquivos.tipo = "pri"
                        AND arquivos.status = 1
                WHERE
                    event_rating.user_id = ?
                GROUP BY event_rating.id
                ORDER BY event_rating.date DESC)
                
                UNION

                (SELECT 
                    event_certificate.id,
                    event_certificate.user_id,
                    event_certificate.event_id,
                    CONCAT("Participou como <b>", event_follow.office, "</b>") as text,
                    event_certificate.date,
                    arquivos.arquivo,
                    event.event_name,
                    "event_certificate" AS activity_type,
                    0 AS rating,
                    event.event_url
                FROM
                    event_certificate
                    INNER JOIN event ON event.id = event_certificate.event_id
                        AND event.status = 1
                    INNER JOIN event_follow ON event_follow.event_id = event.id
                        AND event_follow.user_id = event_certificate.user_id
                    LEFT JOIN arquivos ON arquivos.tabela = "event"
                        AND arquivos.referencia = event.id
                        AND arquivos.tipo = "pri"
                WHERE
                    event_certificate.user_id = ?
                    AND event_certificate.status = 1
                GROUP BY event_certificate.id
                ORDER BY event_certificate.date DESC)

                UNION
                
                (SELECT 
                    company_rating.id,
                    company_rating.user_id,
                    company_rating.company_id as event_id,
                    CONCAT("<b>Comentou na empresa: </b>", company_rating.company_rating_commentary) AS text,
                    company_rating.date,
                    arquivos.arquivo,
                    company.company_name AS event_name,
                    "company_rating" AS activity_type,
                    company_rating.company_rating_rate AS rating,
                    "" AS event_url
                FROM
                    company_rating
                    INNER JOIN company ON company.id = company_rating.company_id
                        AND company.status = 1
                    LEFT JOIN arquivos ON arquivos.tabela = "company"
                        AND arquivos.referencia = company.id
                        AND arquivos.tipo = "pri"
                        AND arquivos.status = 1
                WHERE
                    company_rating.user_id = ?
                GROUP BY company_rating.id
                ORDER BY company_rating.date DESC)
                
                ORDER BY date DESC
                LIMIT '.($page*5).', 5';
            
            $Database = new Database();
            $queryResult = $Database->query($sql, [$this->id, $this->id, $this->id, $this->id, $this->id]);
            
            if ($queryResult === false)
                return false;

            $objsResult = array();
            foreach ($queryResult['result'] as $result) {
                $objsResult[] = new UserFeed($result);
            }
            return $objsResult;
        }

        function getInterestEvents() {
            return Event::getBy([
                Event::_TABLE.'.status' => 1,
                '('.Event::_TABLE.'.event_start_date >= NOW())' => 1
            ], [
                Event::_TABLE.'.event_name as name',
                Event::_TABLE.'.id'
            ], false, [
                EventFollow::_TABLE => [
                    EventFollow::_TABLE . '.event_id' => Event::_TABLE . '.id',
                    EventFollow::_TABLE . '.user_id' => $this->id
                ]
            ], [], [], [], Event::_TABLE.'.event_name');
        }

        function calculateCoordinates() {
            $sql = 'SELECT city.name as city, state.name as state FROM eventy.city JOIN state ON state.id = city.state_id WHERE city.id = ?';
            $Database = new Database;
            $queryResult = $Database->query($sql, [$this->city_id]);
            $cityState = @$queryResult['result'][0];

            $address = "{$this->address_street}, {$this->address_number} - {$this->address_neightborhood}, {$cityState['city']} - {$cityState['state']}";
            $url = 'https://maps.googleapis.com/maps/api/geocode/json?address='.urlencode($address).'&key=' . GOOGLE_MAPS_KEY;

            $curl = curl_init();

            curl_setopt($curl, CURLOPT_URL, $url);
            curl_setopt($curl, CURLOPT_RETURNTRANSFER, true); 

            $response = curl_exec($curl);
            $status = curl_getinfo($curl,CURLINFO_HTTP_CODE);
            curl_close($curl);

            $jsonResponse = json_decode($response);

            if ($jsonResponse->status !== 'OK')
                return null;
            
            return new Point($jsonResponse->results[0]->geometry->location->lat, $jsonResponse->results[0]->geometry->location->lng);
        }

        function getUrl() {
            return SITE_URL . 'perfil/' . $this->id;
        }
    }
?>