<?php

    trait Model {
        function __construct($values) {
            if (!is_array(self::_require)) throw new Exception('Atributos necessários mal definidos em '.get_called_class());
            if (empty(self::_key)) throw new Exception('Chave não definida para '.get_called_class());
            if (!is_array($values)) throw new Exception('Inicializou model '.get_called_class().' com valores não interpretáveis');

            $this->set($values);
        }

        function __invoke($format) {
            if ($format === 'json')
                return json_encode($this);
        }

        function set($values) {
            foreach ($values as $property => $value) {
                if (defined(get_called_class().'::_filters') AND in_array($property, array_keys(self::_filters))) {
                    $function = 'filter'.self::_filters[$property];
                    $this->$property = $this->$function($value);
                } else {
                    $this->$property = $value;
                }
            }
        }

        function isValid() {
            foreach (self::_require as $requiredProperty) {
                if (empty($this->$requiredProperty)) {
                    debug_log("$requiredProperty from " . get_called_class() . " is required, but is empty");
                    return false;
                }
            }

            if (!empty(self::_filters))
                foreach (self::_filters as $property => $filter) {
                    $function = 'is'.self::_filters[$property];
                    if ($this->$property AND !$this->$function($this->$property)) {
                        if (self::_filters[$property] == 'Point') {
                            unset($this->$property);
                        } else {
                            debug_log(get_called_class() . "->$property is using an invalid format");
                            return false;
                        }
                    }
                }
            
            return true;
        }

        function save() {
            if (!$this->isValid())
                return false;
            
            $campos = (array) $this;

            foreach (@self::_not_empty as $notEmptyValue) {
                if (is_object(@$campos[$notEmptyValue]) && !($campos[$notEmptyValue] instanceof Point))
                    $campos[$notEmptyValue] = (string)$campos[$notEmptyValue];
                if (empty(@$campos[$notEmptyValue]))
                    unset($campos[$notEmptyValue]);
            }

            $controllerClassName = $this->getControllerClassName();
            
            if (!@$this->id) {
                $this->id = $controllerClassName::insert($campos);
                return $this->id;
            }
            
            return $controllerClassName::update($campos, $this->id);
        }

        function delete() {
            if (!$this->id)
                return false;
            
            $controllerClassName = $this->getControllerClassName();
            return $controllerClassName::delete($this->id);
        }

        function reallyDelete() {
            if (!$this->id)
                return false;
            
            $controllerClassName = $this->getControllerClassName();
            return $controllerClassName::reallyDelete($this->id);
        }

        function getControllerClassName() {
            return str_replace('Model', '', get_called_class());;
        }


        // ! Filtros

        private function filterDate($value) {
            return new Date($value);
        }

        private function isDate($value) {
            $d = DateTime::createFromFormat('Y-m-d', $value('Y-m-d'));
            return $d && $d->format('Y-m-d') == $value('Y-m-d');
        }

        private function filterTime($value) {
            return new Time($value);
        }

        private function isTime($value) {
            $d = DateTime::createFromFormat('H:i:s', $value);
            return $d && $d->format('H:i:s') == $value;
        }

        private function filterTimeDate($value) {
            return new TimeDate($value);
        }

        private function isTimeDate($value) {
            return $value instanceof TimeDate;
        }

        private function filterMoney($value) {
            return new Money($value);
        }

        private function isMoney($value) {
            return is_a($value, 'Money');
        }

        private function filterInt($value) {
            return (int) $value;
        }

        private function isInt($value) {
            return is_numeric($value);
        }

        private function filterPoint($value) {
            if (is_array($value))
                return new Point(reset($value), end($value));
            return $value;
        }

        private function isPoint($value) {
            return ($value instanceof Point);
        }

        private function filterMail($value) {
            return $value;
        }

        private function isMail($value) {
            return (bool)filter_var($value, FILTER_VALIDATE_EMAIL);
        }
    }

?>